import QtQuick 2.0
import QtQuick.XmlListModel 2.0

import "Config.js" as Config
import "global.js" as Global
import XmlLoader 1.0


Item
{
    id: cityLoader

    width: Config.CityLoadWidgetWidth
    height: Config.CityLoadWidgetHeight

    property DataLoader dataLoaderObj: DataLoader{
        proxyHostName : Config.ProxyHostName
        proxyHostPort : Config.ProxyHostPort

		dataUrl: Config.DataUrl
        updateTime: Config.DataUpdateTime

        onDataChanged: {
            cityLoadLevel.loadLevelValue = dataLoaderObj.cityLoadLevel;
            if( !drumTimer.running && Config.CityBannerImageVisible )
                drumTimer.start()
        }
    }

    property FontLoader cityFontLoader: FontLoader { source: Config.CityLoadTextFontSource }

    Behavior on y { NumberAnimation{ easing.type: Easing.Linear; duration: Config.CityLoadAnimationDuration } }


    HighwayLoadItemBase
    {
        id: bannerItem

        scrollDirection: Config.CityLoadScrollDirection
        animationDuration : Config.CityLoadAnimationDuration

        state: Config.CityLoadScrollDirection ? Global.stateInactive : Global.stateDisactive

        Image
        {
            source: Config.CityBannerSourceFile
            x: Config.CityBannerImageXPos
            y: Config.CityBannerImageYPos
            width: Config.CityBannerImageWidth
            height: Config.CityBannerImageHeight
        }
    }

    HighwayLoadItemBase
    {
        id: loadLevelItem
        scrollDirection: Config.CityLoadScrollDirection
        animationDuration : Config.CityLoadAnimationDuration
        state: Global.stateActive

        LoadLevelItem
        {
            id: cityLoadLevel
            width: parent.width
            height: parent.height
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            //loadLevelValue: 0
            loadLevelTextEnable:      Config.CityLoadTextVisible
            loadLevelTextColorful:    Config.CityLoadTextColorful
            loadLevelTextXPosition:   Config.CityLoadTextX
            loadLevelTextYPosition:   Config.CityLoadTextY
            loadLevelTextLong:        Config.CityLoadTextLong
            loadLevelTextLongX:        Config.CityLoadTextLongX
            loadLevelTextLongY:        Config.CityLoadTextLongY
            loadLevelTextFontSize:    Config.CityLoadTextFontSize
            loadLevelTextFontFamily:  cityFontLoader.name
            loadLevelTextFontWeight:  Config.CityLoadLevelFontBold
            loadLevelTextUnitFontBold: Config.CityLoadLevelUnitFontBold
            loadLevelTextColorDefault: Config.CityLoadTextColorDefault
            loadLevelTextColorGreen:  Config.CityLoadTextColorGreen
            loadLevelTextColorYellow: Config.CityLoadTextColorYellow
            loadLevelTextColorRed:    Config.CityLoadTextColorRed
            loadLevelIconEnable:      Config.CityLoadImageVisible
            loadLevelIconXPosition:   Config.CityLoadImageX
            loadLevelIconYPosition:   Config.CityLoadImageY
            loadLevelIconWidth:       Config.CityLoadImageWidth
            loadLevelIconHeight:      Config.CityLoadImageHeight
            loadLevelRingVisible:     Config.CityLoadLevelRingVisible
            loadLevelRingPosX:        Config.CityLoadLevelRingPosX
            loadLevelRingPosY:        Config.CityLoadLevelRingPosY
            loadLevelRingSize:       Config.CityLoadLevelRingWidth
        }
    }

    Timer
    {
        property bool showBanner : false
        id: bannerTimer
        running: Config.CityBannerImageVisible
        interval: Config.CityBannerImageShowInterval
        onTriggered: { showBanner = true }
    }

    Timer
    {
        id: drumTimer
        interval: Config.CityBannerImageShowDuration / 2
        repeat: true
        onTriggered:
        {
            if( Config.CityLoadScrollDirection )
            {
                if(!bannerTimer.showBanner)
                {
                    if( bannerItem.state !== Global.stateInactive )
                        bannerItem.getNextState();
                    if( loadLevelItem.state !== Global.stateActive )
                        loadLevelItem.getNextState();
                }
                else
                {
                    if( bannerItem.state === Global.stateInactive )
                    {
                       bannerItem.getNextState();
                       loadLevelItem.getNextState();
                    }
                    else if( bannerItem.state == Global.stateActive )
                    {
                        bannerTimer.showBanner = false;
                        bannerTimer.start();
                        loadLevelItem.getNextState();
                    }
                }

            }
            else
            {
                if(!bannerTimer.showBanner)
                {
                    if( bannerItem.state !== Global.stateDisactive )
                        bannerItem.getNextState();
                    if( loadLevelItem.state !== Global.stateActive )
                        loadLevelItem.getNextState();
                }
                else
                {
                    if( bannerItem.state === Global.stateDisactive )
                    {
                       bannerItem.getNextState();
                       loadLevelItem.getNextState();
                    }
                    else if( bannerItem.state == Global.stateActive )
                    {
                        bannerTimer.showBanner = false;
                        bannerTimer.start();
                        loadLevelItem.getNextState();
                    }
                }
            }
        }
    }
}
