import QtQuick 2.0

import "Config.js" as Conf

Item
{
    id: parentItem
    property int    loadLevelValue : -1
    property bool   loadLevelTextEnable
    property bool   loadLevelTextColorful
    property int    loadLevelTextXPosition
    property int    loadLevelTextYPosition
    property bool   loadLevelTextLong
    property int    loadLevelTextLongX
    property int    loadLevelTextLongY
    property int    loadLevelTextFontSize
    property color  loadLevelTextColorDefault
    property color  loadLevelTextColorGreen
    property color  loadLevelTextColorYellow
    property color  loadLevelTextColorRed
    property string loadLevelTextFontFamily

    property bool loadLevelTextFontWeight
    property bool loadLevelTextUnitFontBold

    property bool loadLevelIconEnable
    property int  loadLevelIconXPosition
    property int  loadLevelIconYPosition
    property int  loadLevelIconWidth
    property int  loadLevelIconHeight

    property bool loadLevelRingVisible
    property int loadLevelRingPosX
    property int loadLevelRingPosY
    property int loadLevelRingSize

    property int paintedWidth


    function makeTextBoldForNeed( text, need )
    {
        if( need )
            return "<b>" + text + "</b>";
        else
            return text;
    }

    onLoadLevelValueChanged: {
        loadLevelTextItem.visible = ( loadLevelTextEnable && loadLevelValue >= 0 )
        loadLevelLongTextItem.visible = (loadLevelTextItem.visible && loadLevelTextLong )
        loadLevelTextItem.text = makeTextBoldForNeed( loadLevelValue, loadLevelTextUnitFontBold );
        if( loadLevelTextLong )
        {
            if( loadLevelValue === 1 )
                loadLevelLongTextItem.text = makeTextBoldForNeed( "балл", loadLevelTextFontWeight );
            else if ( loadLevelValue >=2 && loadLevelValue <=4 )
                loadLevelLongTextItem.text = makeTextBoldForNeed( "балла", loadLevelTextFontWeight );
            else if ( loadLevelValue >=5 || loadLevelValue === 0 )
                loadLevelLongTextItem.text = makeTextBoldForNeed( "баллов", loadLevelTextFontWeight );
        }

        paintedWidth = loadLevelTextItem.paintedWidth + loadLevelLongTextItem.paintedWidth + 35
    }

    ColorfulText
    {
        id: loadLevelTextItem
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        font.pointSize: loadLevelTextFontSize - 1
        font.family: loadLevelTextFontFamily
        x: loadLevelTextXPosition
        y: loadLevelTextYPosition
        z: 1

        isColorful: loadLevelTextColorful
        loadlLevelValue: loadLevelValue
        colorDefault: loadLevelTextColorDefault
        colorGreen: loadLevelTextColorGreen
        colorYellow: loadLevelTextColorYellow
        colorRed: loadLevelTextColorRed
    }

    Image
    {
        id: loadLevelTextItemRing
        visible: loadLevelRingVisible
        source: {
            if( loadLevelValue >= 0 && loadLevelValue <= 3 ) "images/green.png"
            else if ( loadLevelValue >= 4 && loadLevelValue <= 6 ) "images/yellow.png"
            else if ( loadLevelValue >=7 && loadLevelValue <=10 ) "images/red.png"
            else "";
        }
        x: loadLevelRingPosX
        y: loadLevelRingPosY
        fillMode: Image.Stretch
        cache: false
        width: loadLevelRingSize - 1
        height: loadLevelRingSize - 1
    }

    ColorfulText
    {
        id: loadLevelLongTextItem
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        font.pointSize: loadLevelTextFontSize - 1
        font.family: loadLevelTextFontFamily

        isColorful: loadLevelTextColorful
        loadlLevelValue: loadLevelValue
        colorDefault: loadLevelTextColorDefault
        colorGreen: loadLevelTextColorGreen
        colorYellow: loadLevelTextColorYellow
        colorRed: loadLevelTextColorRed

        x: loadLevelTextLongX
        y: loadLevelTextLongY

    }

    Image
    {
        id: loadLevelIconItem
        x: loadLevelIconXPosition
        y: loadLevelIconYPosition
        width: loadLevelIconWidth
        height: loadLevelIconHeight
        cache: false

        source: {
            if( Conf.CityLoadImageTrafficDay )
            {
                if( Conf.CityLoadImageTrafficDirection )
                {
                    if( loadLevelValue >= 0 && loadLevelValue <= 3 ) "images/green_traffic_day_left.png"
                    else if ( loadLevelValue >= 4 && loadLevelValue <= 6 ) "images/yellow_traffic_day_left.png"
                    else if ( loadLevelValue >=7 && loadLevelValue <=10 ) "images/red_traffic_day_left.png"
                    else "";
                }
                else
                {
                    if( loadLevelValue >= 0 && loadLevelValue <= 3 ) "images/green_traffic_day_right.png"
                    else if ( loadLevelValue >= 4 && loadLevelValue <= 6 ) "images/yellow_traffic_day_right.png"
                    else if ( loadLevelValue >=7 && loadLevelValue <=10 ) "images/red_traffic_day_right.png"
                    else "";
                }
            }
            else
            {
                if( Conf.CityLoadImageTrafficDirection )
                {
                    if( loadLevelValue >= 0 && loadLevelValue <= 3 ) "images/green_traffic_night_left.png"
                    else if ( loadLevelValue >= 4 && loadLevelValue <= 6 ) "images/yellow_traffic_night_left.png"
                    else if ( loadLevelValue >=7 && loadLevelValue <=10 ) "images/red_traffic_night_left.png"
                    else "";
                }
                else
                {
                    if( loadLevelValue >= 0 && loadLevelValue <= 3 ) "images/green_traffic_night_right.png"
                    else if ( loadLevelValue >= 4 && loadLevelValue <= 6 ) "images/yellow_traffic_night_right.png"
                    else if ( loadLevelValue >=7 && loadLevelValue <=10 ) "images/red_traffic_night_right.png"
                    else "";
                }
            }
        }
        visible : ( loadLevelIconEnable && loadLevelValue >= 0 )
    }

}
