#ifndef CDATALOADER_H
#define CDATALOADER_H

#include <QObject>
#include <QUrl>
#include <QNetworkAccessManager>
#include <QMultiMap>
#include <QTimer>

#include "street.h"
#include "streetload.h"


class CDataLoader : public QObject
{
	Q_OBJECT

	Q_PROPERTY(QUrl dataUrl READ dataUrl WRITE setDataUrl NOTIFY dataUrlChanged)
	Q_PROPERTY(uint updateTime READ updateTime WRITE setUpdateTime NOTIFY updateTimeChanged)
	Q_PROPERTY(uint cityLoadLevel READ cityLoadLevel NOTIFY dataChanged)
	Q_PROPERTY(bool makeSubstitution READ makeSubstitution WRITE setMakeSubstitution NOTIFY makeSubstitutionChanged)
	Q_PROPERTY(QUrl substitutionUrl READ substitutionUrl WRITE setSubstitutionUrl NOTIFY makeSubstitutionChanged)

	Q_PROPERTY(uint streetsCount READ streetsCount NOTIFY dataChanged)
	Q_PROPERTY(uint directionsCount READ directionsCount NOTIFY dataChanged)

	Q_PROPERTY(QString proxyHostName READ proxyHostName WRITE setProxyHostName NOTIFY proxyChanged )
	Q_PROPERTY(uint proxyHostPort READ proxyHostPort WRITE setProxyHostPort NOTIFY proxyChanged)

public:
	explicit CDataLoader(QObject *parent = 0);
	~CDataLoader();

	void setDataUrl( const QUrl& newUrl );
	QUrl dataUrl() const;
	void setUpdateTime( uint updateTime );
	unsigned int updateTime() const;

	QString proxyHostName() const;
	void setProxyHostName(const QString& _host);

	uint proxyHostPort() const;
	void setProxyHostPort(uint _port);
	
	bool makeSubstitution() const;
	void setMakeSubstitution(bool);
	QUrl substitutionUrl() const;
	void setSubstitutionUrl(const QUrl& url);

	unsigned int streetsCount() const;
	unsigned int directionsCount() const;

	Q_INVOKABLE QString getStreetTitle(uint streetIndex);
	Q_INVOKABLE unsigned int getStreetCountDirections(uint streetIndex);

	Q_INVOKABLE unsigned int getDirectionLevel(uint streetIndex, uint directionIndex = 0);
	Q_INVOKABLE QString getDirectionName(uint streetIndex, uint directionIndex = 0);

	Q_INVOKABLE unsigned int cityLoadLevel() const { return m_uiCityLoadLevel; }
signals:
	void dataUrlChanged();
	void dataChanged();
	void updateTimeChanged();
	void makeSubstitutionChanged();
	void proxyChanged();

public slots:
	void updateData();

private slots:
	void dataLoaded(QNetworkReply*);

	void loadSubstition();
	void changeProxy();
private:
	QNetworkAccessManager* m_manager;
	QUrl m_url;

	uint m_uiCityLoadLevel;

	QVector<Street*> m_streets;
	QMap<QString,QString> m_substitutions;//name and title
	QTimer* m_timer;
	QUrl m_substUrl;
	bool m_makeSubst;

	QString m_strProxyName;
	uint m_uiProxyPort;
};

#endif // CDATALOADER_H
